#!/usr/bin/env python3

import numpy as np
from scipy.fftpack import fft, fftshift
from scipy.signal import blackman
import matplotlib.pyplot as plt
import scipy.io.wavfile

import sys

# Parameters

N = 2**10
averaging = 2

samp_rate, samples = scipy.io.wavfile.read(sys.argv[1])

total_transforms = len(samples)//(N//2) - 1
lines = total_transforms//averaging

window = blackman(N)

waterfall = np.empty((lines, N//2))

for line in range(lines):
    transforms = np.zeros((averaging, N//2), dtype=np.float32)
    for transform in range(averaging):
        start = (line * averaging + transform)*N//2
        f = fft(samples[start:start+N] * window)[:N//2]
        transforms[transform,:] = np.real(f)**2 + np.imag(f)**2
        waterfall[line,:] = 10*np.log10(np.average(transforms, axis=0)) - 20*np.log10(N)

plt.imsave(sys.argv[1] + '.png', waterfall[:,::-1].T, vmin=30, vmax=55, cmap='viridis', origin='bottom')

